aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--images/b_edit.pngbin0 -> 451 bytes
-rw-r--r--tagedit.php2
-rw-r--r--templates/bookmarks.tpl.php14
3 files changed, 12 insertions, 4 deletions
diff --git a/images/b_edit.png b/images/b_edit.png
new file mode 100644
index 0000000..05711a0
--- /dev/null
+++ b/images/b_edit.png
Binary files differ
diff --git a/tagedit.php b/tagedit.php
index 57a9466..e7b46a1 100644
--- a/tagedit.php
+++ b/tagedit.php
@@ -47,7 +47,7 @@ if(!$userservice->isLoggedOn()) {
if (POST_CONFIRM) {
if ( strlen($tag)>0 &&
- $tagservice->updateDescription($tag, $currentUser->getId(), POST_DESCRIPTION)
+ $tagservice->updateDescription($tag, $currentUser->getId(), stripslashes(POST_DESCRIPTION))
) {
$tplVars['msg'] = T_('Tag description updated');
header('Location: '. POST_REFERRER);
diff --git a/templates/bookmarks.tpl.php b/templates/bookmarks.tpl.php
index 2b30d87..c95e129 100644
--- a/templates/bookmarks.tpl.php
+++ b/templates/bookmarks.tpl.php
@@ -45,8 +45,8 @@ if(isset($currenttag) && $currenttag!= '' && $cdservice->getLastTagDescription($
//common tag description edit
if($userservice->isLoggedOn()) {
if(isset($currenttag) && $currenttag!= '') {
- echo ' (<a href="'. createURL('tagcommondescriptionedit', $currenttag).'">';
- echo T_('edit common description').'</a>)';
+ echo ' <a href="'. createURL('tagcommondescriptionedit', $currenttag).'">';
+ echo T_('common description').' <img src="'.ROOT.'images/b_edit.png" /></a>';
} elseif(isset($hash)) {
echo ' (<a href="'.createURL('bookmarkcommondescriptionedit', $hash).'">';
echo T_('edit common description').'</a>)';
@@ -57,7 +57,7 @@ if($userservice->isLoggedOn()) {
<?php
/* Private tag description */
if(isset($currenttag) && $currenttag!= '' && isset($user)) {
$userObject = $userservice->getUserByUsername($user);
if($tagservice->getDescription($currenttag, $userObject['uId'])) { ?>
@@ -65,6 +65,14 @@ if(isset($currenttag) && $currenttag!= '' && isset($user)) {
<p class="commondescription"><?php
$description = $tagservice->getDescription($currenttag, $userObject['uId']);
echo nl2br(filter($description['tDescription']));
+
+//personal tag description edit
+if($userservice->isLoggedOn()) {
+ if(isset($currenttag) && $currenttag!= '') {
+ echo ' <a href="'. createURL('tagedit', $currenttag).'">';
+ echo T_('personal description').' <img src="'.ROOT.'images/b_edit.png" /></a>';
+ }
+}
?></p>
<?php
@@ -57,7 +57,7 @@ if($userservice->isLoggedOn()) {
<?php
-/* Private tag description */
+/* personal tag description */
if(isset($currenttag) && $currenttag!= '' && isset($user)) {
$userObject = $userservice->getUserByUsername($user);